@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Dict, List
+from typing import Dict, Iterable, List
 from pybmd.folder import Folder
 from pybmd.media_pool_item import MediaPoolItem
 from pybmd.timeline import Timeline
@@ -62,7 +62,7 @@ class MediaPool():
     def create_empty_timeline(self, name) -> Timeline:
         return Timeline(self.media_pool.CreateEmptyTimeline(name))
 
-    @dispatch(str, List[MediaPoolItem])
+    @dispatch(str, Iterable)
     def create_timeline_from_clips(self, name: str, clips: List[MediaPoolItem]) -> Timeline:  # type: ignore
         return Timeline(self.media_pool.CreateTimelineFromClips(name, [clip.media_pool_item for clip in clips]))
 
